pub struct ContinuousRng { /* private fields */ }Expand description
A continuous random number generator that works in no-std contexts.
Implementations
Sourceimpl ContinuousRng
impl ContinuousRng
Sourcepub fn new(seed: [u8; 32]) -> ContinuousRng
pub fn new(seed: [u8; 32]) -> ContinuousRng
Creates a new instance of the random number generator from the seed.
Sourcepub fn value<T: Randomizable>(&mut self) -> T
pub fn value<T: Randomizable>(&mut self) -> T
Generates a random value of the Randomizable type T.