pub struct RandomCoin { /* private fields */ }Expand description
A simplified version of the SPONGE_PRG reseedable pseudo-random number generator algorithm
described in https://eprint.iacr.org/2011/499.pdf.
The simplification is related to the following facts:
- A call to the reseed method implies one and only one call to the permutation function. This is possible because in our case we never reseed with more than 4 field elements.
- As a result of the previous point, we don’t make use of an input buffer to accumulate seed material.
Implementations
Sourceimpl RandomCoin
impl RandomCoin
Sourcepub fn new(seed: Word) -> Self
pub fn new(seed: Word) -> Self
Returns a new RandomCoin initialized with the specified seed.
Sourcepub fn from_parts(state: [Felt; 12], current: usize) -> Self
pub fn from_parts(state: [Felt; 12], current: usize) -> Self
Returns a RandomCoin instantiated from the provided components.
Panics
Panics if current is outside of the rate range.
Sourcepub fn into_parts(self) -> ([Felt; 12], usize)
pub fn into_parts(self) -> ([Felt; 12], usize)
Returns components of this random coin.
Sourcepub fn fill_bytes(&mut self, dest: &mut [u8])
pub fn fill_bytes(&mut self, dest: &mut [u8])
Fills dest with random data.
Sourcepub fn draw_basefield(&mut self) -> Felt
pub fn draw_basefield(&mut self) -> Felt
Draws a random base field element from the random coin.
This method applies the Poseidon2 permutation when the rate portion of the state is exhausted, then returns the next element from the rate portion.
Sourcepub fn draw(&mut self) -> Felt
pub fn draw(&mut self) -> Felt
Draws a random field element.
This is an alias for Self::draw_basefield.
Sourcepub fn draw_ext_field<E: ExtensionField<Felt>>(&mut self) -> E
pub fn draw_ext_field<E: ExtensionField<Felt>>(&mut self) -> E
Draws a random extension field element.
The extension field element is constructed by drawing E::DIMENSION base field elements
and interpreting them as basis coefficients.